#!/usr/bin/python
'''
    Copyright 2009, 2010 Oskar Andreasson

    This file is part of EveConsole.

    EveConsole is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    EveConsole is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with EveConsole.  If not, see <http://www.gnu.org/licenses/>.

@author: oan
'''
from pyEveApi.IndustryJobs import IndustryJobs
from pyEveApi.SaveCharacter import SaveCharacter 
from pyEveApi.ItemDB import ItemDB
from datetime import datetime, timedelta
import pyEveApi.debugger as debugger

BLUE = '\033[94m'
GREEN = '\033[92m'
YELLOW = '\033[93m'
RED = '\033[91m'
ENDC = '\033[0m'

if __name__ == '__main__':
    debugger.DBUG(3, "Start")

    items = ItemDB()
    char = SaveCharacter()
    char.loadCache()
    jobs = IndustryJobs(char.getUserID(), 
                           char.getApiKey(), 
                           char.getCharacterID())

    print "Time to next cache update: ", 
    d1 =  jobs.cachedUntil - datetime.now()
    print str(d1)

    print BLUE + "Manufacturing jobs" + ENDC
    print BLUE + str("BPO").ljust(41),
    print str("Runs").ljust(5),
    print str("Start").ljust(20),
    print str("End").ljust(20) + ENDC
    totalPrice = 0
    for node in jobs.getProductionJobsByFinishTime():
            if int(node["activityID"]) == 1:
                if int(node["completed"]) == 0:
                    name = items.getName(int(node["installedItemTypeID"]))
                    startTime = datetime.strptime((node["beginProductionTime"]),
                        "%Y-%m-%d %H:%M:%S") + timedelta(hours=1)
                    endTime = datetime.strptime((node["endProductionTime"]),
                        "%Y-%m-%d %H:%M:%S") + timedelta(hours=1)
                    runs = int(node["runs"])
                    if endTime < datetime.now():
                        print GREEN + str(name).ljust(41),
                    elif startTime < datetime.now():
                        print YELLOW + str(name).ljust(41),
                    else:
                        print RED + str(name).ljust(41),
                    print str(runs).ljust(5),
                    print str(startTime).ljust(20),
                    print str(endTime).ljust(20) + ENDC

    print BLUE + "\nResearching Time Productivity jobs" + ENDC
    print BLUE + str("BPO").ljust(41),
    print str("Runs").ljust(5),
    print str("Start").ljust(20),
    print str("End").ljust(20) + ENDC
    totalPrice = 0
    for node in jobs.getProductionJobsByFinishTime():
            if int(node["activityID"]) == 3:
                if int(node["completed"]) == 0:
                    name = items.getName(int(node["installedItemTypeID"]))
                    startTime = datetime.strptime((node["beginProductionTime"]),
                        "%Y-%m-%d %H:%M:%S") + timedelta(hours=1)
                    endTime = datetime.strptime((node["endProductionTime"]),
                        "%Y-%m-%d %H:%M:%S") + timedelta(hours=1)
                    runs = int(node["runs"])
                    if endTime < datetime.now():
                        print GREEN + str(name).ljust(41),
                    elif startTime < datetime.now():
                        print YELLOW + str(name).ljust(41),
                    else:
                        print RED + str(name).ljust(41),
                    print str(runs).ljust(5),
                    print str(startTime).ljust(20),
                    print str(endTime).ljust(20) + ENDC

    print BLUE + "\nResearching Material Productivity jobs" + ENDC
    print BLUE + str("BPO").ljust(41),
    print str("Runs").ljust(5),
    print str("Start").ljust(20),
    print str("End").ljust(20) + ENDC
    totalPrice = 0
    for node in jobs.getProductionJobsByFinishTime():
            if int(node["activityID"]) == 4:
                if int(node["completed"]) == 0:
                    name = items.getName(int(node["installedItemTypeID"]))
                    startTime = datetime.strptime((node["beginProductionTime"]),
                        "%Y-%m-%d %H:%M:%S") + timedelta(hours=1)
                    endTime = datetime.strptime((node["endProductionTime"]),
                        "%Y-%m-%d %H:%M:%S") + timedelta(hours=1)
                    runs = int(node["runs"])
                    if endTime < datetime.now():
                        print GREEN + str(name).ljust(41),
                    elif startTime < datetime.now():
                        print YELLOW + str(name).ljust(41),
                    else:
                        print RED + str(name).ljust(41),                    
                    print str(runs).ljust(5),
                    print str(startTime).ljust(20),
                    print str(endTime).ljust(20) + ENDC
