#!/usr/bin/python
'''
    Copyright 2009, 2010 Oskar Andreasson

    This file is part of EveConsole.

    EveConsole is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    EveConsole is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with EveConsole.  If not, see <http://www.gnu.org/licenses/>.

@author: oan
'''
from pyEveApi.MarketOrders import MarketOrders
from pyEveApi.SaveCharacter import SaveCharacter
from pyEveApi.ItemDB import ItemDB
from datetime import datetime
import pyEveApi.debugger as debugger

BLUE = '\033[94m'
GREEN = '\033[92m'
YELLOW = '\033[93m'
RED = '\033[91m'
ENDC = '\033[0m'

if __name__ == '__main__':
    debugger.DBUG(3, "Start")

    items = ItemDB()
    char = SaveCharacter()
    char.loadCache()

    try:
        orders = MarketOrders(char.getUserID(),
                                char.getApiKey(),
                                char.getCharacterID())
    except Exception as e:
        print e
        exit()

    print "Time to next cache update: ", 
    d1 =  orders.cachedUntil - datetime.now()
    print str(d1)

    print BLUE + "Sell orders" + ENDC
    print BLUE + str("Name").ljust(40),
    print str("Left/Entered").rjust(20),
    print str("Price").rjust(14) + ENDC
    totalPrice = 0
    nodes = orders.getSellOrdersByName(items)
    for node in nodes:
        name = items.getName(int(node["typeID"]))
        volrem = str(node["volRemaining"]) 
        voltot = str(node["volEntered"]) 
        price = str(node["price"])
        print str(name).ljust(40),
        print str(volrem + "/" + voltot).rjust(20),
        print str(price).rjust(14)
        totalPrice += float(price) * float(volrem)
    print str(BLUE + "Total"),
    print str(totalPrice).rjust(70) + ENDC 

    print BLUE + "\nBuy orders" + ENDC
    print BLUE + str("Name").ljust(40),
    print str("Left/Entered").rjust(20),
    print str("Price").rjust(14) + ENDC
    totalPrice = 0
    nodes = orders.getBuyOrdersByName(items)
    for node in nodes:
        name = items.getName(int(node["typeID"]))
        volrem = str(node["volRemaining"]) 
        voltot = str(node["volEntered"]) 
        price = str(node["price"])
        print str(name).ljust(40),
        print str(volrem + "/" + voltot).rjust(20),
        print str(price).rjust(14)
        totalPrice += float(price) * float(volrem)
    print str(BLUE + "Total"),
    print str(totalPrice).rjust(70) + ENDC 
